==> react-rte-filepicker-0.1.3.tgz: package/src/RichTextEditor.jsx <==
import React, { PropTypes } from 'react';
import {
  AtomicBlockUtils,
  Editor,
  EditorState,
  RichUtils,
  CompositeDecorator,
  Entity
} from 'draft-js';
import { stateToMarkdown } from 'draft-js-export-markdown';
import BlockStyleControls from './BlockStyleControls';
import InlineStyleControls from './InlineStyleControls';
import LinkControls from './LinkControls';
import ImageControls from './ImageControls';
import Link from './Link';
import Media from './Media';

class RichTextEditor extends React.Component {
  constructor(props) {
    super(props);

    this.findLinkEntities = (contentBlock, callback) => {
      contentBlock.findEntityRanges((character) => {
        const entityKey = character.getEntity();
        return (entityKey !== null && Entity.get(entityKey).getType() === 'LINK');
      }, callback);
    };

    this.decorator = new CompositeDecorator([
      {
        strategy: this.findLinkEntities,
        component: Link
      }
    ]);

    this.state = {
      editorState: EditorState.createEmpty(this.decorator)
    };

    this.focus = () => this.refs.editor.focus();
    this.onChange = (editorState) => this.setState({ editorState });

    // This should be called on parent component: this.refs.editor.getMarkdown()
    this.getMarkdown = () => {
      let contentState = this.state.editorState.getCurrentContent();
      return stateToMarkdown(contentState);
    };

    this.blockTypes = [
      { icon: 'header', style: 'header-one' },
      { icon: 'mini header', style: 'header-two' },
      { icon: 'quote left', style: 'blockquote' },
      { icon: 'list', style: 'unordered-list-item' },
      { icon: 'ordered list', style: 'ordered-list-item' },
      { icon: 'code', style: 'code-block' },
    ];

    this.inlineStyles = [
      { icon: 'bold', style: 'BOLD' },
      { icon: 'italic', style: 'ITALIC' },
      { icon: 'underline', style: 'UNDERLINE' },
      { icon: 'code', style: 'CODE' },
    ];
  }

  handleKeyCommand(command) {
    const { editorState } = this.state;
    const newState = RichUtils.handleKeyCommand(editorState, command);
    if (newState) {
      this.onChange(newState);
      return true;
    }
    return false;
  }

  toggleBlockType(blockType) {
    this.onChange(RichUtils.toggleBlockType(this.state.editorState, blockType));
  }

  toggleInlineStyle(inlineStyle) {
    this.onChange(RichUtils.toggleInlineStyle(this.state.editorState, inlineStyle));
  }

  confirmLink(urlValue) {
    const { editorState } = this.state;
    const entityKey = Entity.create('LINK', 'MUTABLE', { url: urlValue });
    this.setState({
      editorState: RichUtils.toggleLink(editorState, editorState.getSelection(), entityKey)
    }, () => {
      setTimeout(() => this.refs.editor.focus(), 0);
    });
  }

  removeLink() {
    const { editorState } = this.state;
    const selection = editorState.getSelection();
    if (!selection.isCollapsed()) {
      this.setState({
        editorState: RichUtils.toggleLink(editorState, selection, null)
      });
    }
  }

  blockRenderer(block) {
    if (block.getType() === 'atomic') {
      return { component: Media, editable: false };
    }
    return null;
  }

  insertMedia(entityKey) {
    const { editorState } = this.state;
    this.onChange(AtomicBlockUtils.insertAtomicBlock(
      editorState,
      entityKey,
      ' '
    ));
  }

  render() {
    const { editorState } = this.state;
    const { filePickerKey } = this.props;
    return (
      <div id="rich-text-editor" className="ui segment">
        <BlockStyleControls
          editorState={editorState}
          onToggle={this.toggleBlockType.bind(this)}
          blockTypes={this.blockTypes}
        />
        <InlineStyleControls
          editorState={editorState}
          onToggle={this.toggleInlineStyle.bind(this)}
          inlineStyles={this.inlineStyles}
        />
        <LinkControls
          editorState={editorState}
          confirmLink={this.confirmLink.bind(this)}
          removeLink={this.removeLink.bind(this)}
        />
        <ImageControls
          editorState={editorState}
          insertMedia={this.insertMedia.bind(this)}
          filePickerKey={filePickerKey}
        />

        <div className="editor" onClick={this.focus}>
          <Editor
            blockRendererFn={this.blockRenderer}
            editorState={editorState}
            handleKeyCommand={this.handleKeyCommand.bind(this)}
            onChange={this.onChange}
            placeholder="Tell a story..."
            ref="editor"
            spellCheck={true}
          />
        </div>
      </div>
    );
  }
}

RichTextEditor.props = {
  filePickerKey: PropTypes.string.isRequired,
};

export default RichTextEditor;

==> react-rte-filepicker-0.1.4.tgz: package/src/RichTextEditor.jsx <==
import React, { PropTypes } from 'react';
import {
  AtomicBlockUtils,
  Editor,
  EditorState,
  RichUtils,
  CompositeDecorator,
  Entity
} from 'draft-js';
import { stateToMarkdown } from 'draft-js-export-markdown';
import BlockStyleControls from './BlockStyleControls';
import InlineStyleControls from './InlineStyleControls';
import LinkControls from './LinkControls';
import ImageControls from './ImageControls';
import Link from './Link';
import Media from './Media';

class RichTextEditor extends React.Component {
  constructor(props) {
    super(props);

    this.findLinkEntities = (contentBlock, callback) => {
      contentBlock.findEntityRanges((character) => {
        const entityKey = character.getEntity();
        return (entityKey !== null && Entity.get(entityKey).getType() === 'LINK');
      }, callback);
    };

    this.decorator = new CompositeDecorator([
      {
        strategy: this.findLinkEntities,
        component: Link
      }
    ]);

    this.state = {
      editorState: EditorState.createEmpty(this.decorator)
    };

    this.focus = () => this.refs.editor.focus();
    this.onChange = (editorState) => this.setState({ editorState });

    // This should be called on parent component: this.refs.editor.getMarkdown()
    this.getMarkdown = () => {
      let contentState = this.state.editorState.getCurrentContent();
      return stateToMarkdown(contentState);
    };

    this.blockTypes = [
      { icon: 'header', style: 'header-one' },
      { icon: 'mini header', style: 'header-two' },
      { icon: 'quote left', style: 'blockquote' },
      { icon: 'list', style: 'unordered-list-item' },
      { icon: 'ordered list', style: 'ordered-list-item' },
      { icon: 'code', style: 'code-block' },
    ];

    this.inlineStyles = [
      { icon: 'bold', style: 'BOLD' },
      { icon: 'italic', style: 'ITALIC' },
      { icon: 'underline', style: 'UNDERLINE' },
      { icon: 'code', style: 'CODE' },
    ];
  }

  handleKeyCommand(command) {
    const { editorState } = this.state;
    const newState = RichUtils.handleKeyCommand(editorState, command);
    if (newState) {
      this.onChange(newState);
      return true;
    }
    return false;
  }

  toggleBlockType(blockType) {
    this.onChange(RichUtils.toggleBlockType(this.state.editorState, blockType));
  }

  toggleInlineStyle(inlineStyle) {
    this.onChange(RichUtils.toggleInlineStyle(this.state.editorState, inlineStyle));
  }

  confirmLink(urlValue) {
    const { editorState } = this.state;
    const entityKey = Entity.create('LINK', 'MUTABLE', { url: urlValue });
    this.setState({
      editorState: RichUtils.toggleLink(editorState, editorState.getSelection(), entityKey)
    }, () => {
      setTimeout(() => this.refs.editor.focus(), 0);
    });
  }

  removeLink() {
    const { editorState } = this.state;
    const selection = editorState.getSelection();
    if (!selection.isCollapsed()) {
      this.setState({
        editorState: RichUtils.toggleLink(editorState, selection, null)
      });
    }
  }

  blockRenderer(block) {
    if (block.getType() === 'atomic') {
      return { component: Media, editable: false };
    }
    return null;
  }

  insertMedia(entityKey) {
    const { editorState } = this.state;
    this.onChange(AtomicBlockUtils.insertAtomicBlock(
      editorState,
      entityKey,
      ' '
    ));
  }

  render() {
    const { editorState } = this.state;
    const { filePickerKey } = this.props;
    return (
      <div id="rich-text-editor" className="ui segment">
        <div className="toolbar">
          <BlockStyleControls
            editorState={editorState}
            onToggle={this.toggleBlockType.bind(this)}
            blockTypes={this.blockTypes}
          />
          <InlineStyleControls
            editorState={editorState}
            onToggle={this.toggleInlineStyle.bind(this)}
            inlineStyles={this.inlineStyles}
          />
          <LinkControls
            editorState={editorState}
            confirmLink={this.confirmLink.bind(this)}
            removeLink={this.removeLink.bind(this)}
          />
          <ImageControls
            editorState={editorState}
            insertMedia={this.insertMedia.bind(this)}
            filePickerKey={filePickerKey}
          />
        </div>

        <div className="editor" style={{overflow: 'hidden', height: '75vh'}} onClick={this.focus}>
          <Editor
            blockRendererFn={this.blockRenderer}
            editorState={editorState}
            handleKeyCommand={this.handleKeyCommand.bind(this)}
            onChange={this.onChange}
            placeholder="Tell a story..."
            ref="editor"
            spellCheck={true}
          />
        </div>
      </div>
    );
  }
}

RichTextEditor.props = {
  filePickerKey: PropTypes.string.isRequired,
};

export default RichTextEditor;
